No-op: whitespace.
[libdcp.git] / src / dcp.h
index 1fa7ae0c65e71740fb1cb82ccbe0700edc9fe1b8..ed5e5e3e0f00d8aac3557850513df63dde7c894f 100644 (file)
--- a/src/dcp.h
+++ b/src/dcp.h
@@ -41,7 +41,7 @@ namespace xmlpp {
 namespace dcp
 {
 
-class Content; 
+class Content;
 class Reel;
 class CPL;
 class XMLMetadata;
@@ -50,27 +50,24 @@ class DecryptedKDM;
 class Asset;
 class DCPReadError;
 
-namespace parse {
-       class AssetMap;
-}
-
 /** @class DCP
  *  @brief A class to create or read a DCP.
  */
-       
+
 class DCP : public boost::noncopyable
 {
 public:
        /** Construct a DCP.  You can pass an existing DCP's directory
-        *  as the parameter, or a non-existant folder to create a new
-        *  DCP in.
+        *  as the parameter; alternatively, directory will be created
+        *  if it does not exist.  Note that if you pass an existing DCP
+        *  into this constructor it will not be read until you call ::read().
         *
         *  @param directory Directory containing the DCP's files.
         */
        DCP (boost::filesystem::path directory);
 
        typedef std::list<boost::shared_ptr<DCPReadError> > ReadErrors;
-       
+
        /** Read the DCP's structure into this object.
         *  @param keep_going true to try to keep going in the face of (some) errors.
         *  @param errors List of errors that will be added to if keep_going is true.
@@ -83,16 +80,12 @@ public:
         *  @param note Functor to handle notes made by the equality operation.
         *  @return true if the DCPs are equal according to EqualityOptions, otherwise false.
         */
-       bool equals (DCP const & other, EqualityOptions options, boost::function<void (NoteType, std::string)> note) const;
+       bool equals (DCP const & other, EqualityOptions options, NoteHandler note) const;
 
-       void add (boost::shared_ptr<Asset> asset);
+       void add (boost::shared_ptr<CPL> cpl);
 
        std::list<boost::shared_ptr<CPL> > cpls () const;
-
-       /** @return All this DCP's assets (note that CPLs are assets) */
-       std::list<boost::shared_ptr<Asset> > assets () const {
-               return _assets;
-       }
+       std::list<boost::shared_ptr<Asset> > assets () const;
 
        bool encrypted () const;
 
@@ -115,7 +108,7 @@ private:
                XMLMetadata metadata,
                boost::shared_ptr<const Signer> signer
                ) const;
-       
+
        void write_volindex (Standard standard) const;
 
        /** Write the ASSETMAP file.
@@ -126,8 +119,8 @@ private:
 
        /** the directory that we are writing to */
        boost::filesystem::path _directory;
-       /** the assets that make up this DCP */
-       std::list<boost::shared_ptr<Asset> > _assets;
+       /** the CPLs that make up this DCP */
+       std::list<boost::shared_ptr<CPL> > _cpls;
 };
 
 }